Documentation
¶
Overview ¶
/ recursively spider a program directory
Index ¶
Constants ¶
const ( FS_CREATE = 1 << iota FS_DELETE FS_MODIFY FS_RENAME )
event type
Variables ¶
This section is empty.
Functions ¶
func NewPathSet ¶ added in v0.0.5
func NewPathSet() *pathSetImpl
Types ¶
type Spider ¶
type Spider interface {
// use to watch a path
Spide(path string) error
// use to unwatch a path
UnSpide(path string) error
// return a channel that will receive all the files that have been changed(edited,or created), this method is thread safe
FilesChanged() <-chan string
// return all paths that are being watched, this method is thread safe
AllPaths() []string
// return all files that are being watched, this method is thread safe
AllFiles() []string
// return all dirs that are being watched, this method is thread safe
AllDirs() []string
// stop watching files,releasing all resources, this method is thread safe,
// this function must be called at the end of the life cycle
Stop()
}
Click to show internal directories.
Click to hide internal directories.