Documentation
¶
Overview ¶
/ recursively spider a program directory
Index ¶
Constants ¶
const ( FS_CREATE = 1 << iota FS_DELETE FS_MODIFY FS_RENAME )
event type
Variables ¶
This section is empty.
Functions ¶
func NewPathSet ¶ added in v0.0.5
func NewPathSet() *pathSetImpl
Types ¶
type Spider ¶
type Spider struct {
// contains filtered or unexported fields
}
func (*Spider) AllPaths ¶ added in v0.0.2
return all paths that are being watched, this method is thread safe
func (*Spider) FilesChanged ¶
return a channel that will receive all the files that have been changed(edited,or created), this method is thread safe
Click to show internal directories.
Click to hide internal directories.